/*
 * libdevice-node
 *
 * Copyright (c) 2016 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef __HW_THERMAL_H__
#define __HW_THERMAL_H__

#include <hw/common.h>

/**
 * The id of this device
 */
#define THERMAL_HARDWARE_DEVICE_ID	"thermal"

/**
 * The version of this device
 */
#define THERMAL_HARDWARE_DEVICE_VERSION	MAKE_VERSION(0,1)

typedef enum _thermal_state {
	THERMAL_STATE_LOW,
	THERMAL_STATE_NORMAL,
	THERMAL_STATE_HIGH,
} thermal_state_e;

typedef enum _thermal_level {
	THERMAL_LEVEL_NORMAL = 1001,
	THERMAL_LEVEL_WARNING,
	THERMAL_LEVEL_CRITICAL,
	THERMAL_LEVEL_POWEROFF,
} thermal_level_e;

struct thermal_info {
	thermal_state_e state;
	thermal_level_e level;
};

typedef void (*ThermalUpdated)(struct thermal_info *info, void *data);

struct thermal_device {
	struct hw_common common;

	/* Get thermal state */
	int (*get_state)(struct thermal_info *info);

	/* Register thermal event */
	int (*register_changed_event)(ThermalUpdated updated_cb, void *data);
	int (*unregister_changed_event)(ThermalUpdated updated_cb);
};

#endif /* __HW_THERMAL_H__ */
